@@ -39,8 +39,11 @@
 #include "sysprof-callgraph-aid.h"
 #include "sysprof-counters-aid.h"
 #include "sysprof-cpu-aid.h"
+#include "sysprof-diskstat-aid.h"
 #include "sysprof-logs-aid.h"
 #include "sysprof-marks-aid.h"
+#include "sysprof-netdev-aid.h"
+#include "sysprof-rapl-aid.h"
 
 typedef enum
 {
@@ -630,8 +633,11 @@ sysprof_display_present_async (SysprofDisplay       *self,
   g_ptr_array_add (aids, sysprof_counters_aid_new ());
   g_ptr_array_add (aids, sysprof_cpu_aid_new ());
   g_ptr_array_add (aids, sysprof_callgraph_aid_new ());
+  g_ptr_array_add (aids, sysprof_diskstat_aid_new ());
   g_ptr_array_add (aids, sysprof_logs_aid_new ());
   g_ptr_array_add (aids, sysprof_marks_aid_new ());
+  g_ptr_array_add (aids, sysprof_netdev_aid_new ());
+  g_ptr_array_add (aids, sysprof_rapl_aid_new ());
 
   task = g_task_new (self, cancellable, callback, user_data);
   g_task_set_source_tag (task, sysprof_display_present_async);
